# `pptestopawell` - My simple first project at PyPI

* Op1 name
* Op2 get_numpy_arr
* Op3
* Op4

# Install

```python
pip install pptestopawell
```

## Usage

```python
from pptestopawell.m_mod_pptest import name as n

>>> n("name", "surname")
Witaj: Name, Surname
>>> get_numpy_arr([1, 2, 3, 4, 5])
[1, 2, 3, 4, 5]
```

### End terms
none